# coding: utf-8

"""
IpV6AddressState.py

 The Clear BSD License

 Copyright (c) – 2016, NetApp, Inc. All rights reserved.

 Redistribution and use in source and binary forms, with or without modification, are permitted (subject to the limitations in the disclaimer below) provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

 * Neither the name of NetApp, Inc. nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

 NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

from pprint import pformat
from six import iteritems


class IpV6AddressState(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IpV6AddressState - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'address_type': 'str',  # (required parameter)
            'interface_address_state': 'str',  
            'router_address_state': 'str'
        }

        self.attribute_map = {
            'address_type': 'addressType',  # (required parameter)
            'interface_address_state': 'interfaceAddressState',  
            'router_address_state': 'routerAddressState'
        }

        self._address_type = None
        self._interface_address_state = None
        self._router_address_state = None

    @property
    def address_type(self):
        """
        Gets the address_type of this IpV6AddressState.
        This enumeration defines the two different types of IPV6 addresses - interface or router.

        :return: The address_type of this IpV6AddressState.
        :rtype: str
        :required/optional: required
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """
        Sets the address_type of this IpV6AddressState.
        This enumeration defines the two different types of IPV6 addresses - interface or router.

        :param address_type: The address_type of this IpV6AddressState.
        :type: str
        """
        allowed_values = ["typeInterface", "typeRouter", "__UNDEFINED"]
        if address_type not in allowed_values:
            raise ValueError(
                "Invalid value for `address_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._address_type = address_type

    @property
    def interface_address_state(self):
        """
        Gets the interface_address_state of this IpV6AddressState.
        The interface address state. This field is only valid if addressType is equal to IPV6_ADDR_TYPE_INTERFACE.

        :return: The interface_address_state of this IpV6AddressState.
        :rtype: str
        :required/optional: optional
        """
        return self._interface_address_state

    @interface_address_state.setter
    def interface_address_state(self, interface_address_state):
        """
        Sets the interface_address_state of this IpV6AddressState.
        The interface address state. This field is only valid if addressType is equal to IPV6_ADDR_TYPE_INTERFACE.

        :param interface_address_state: The interface_address_state of this IpV6AddressState.
        :type: str
        """
        allowed_values = ["unconfigured", "acquiring", "configured", "invalid", "__UNDEFINED"]
        if interface_address_state not in allowed_values:
            raise ValueError(
                "Invalid value for `interface_address_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._interface_address_state = interface_address_state

    @property
    def router_address_state(self):
        """
        Gets the router_address_state of this IpV6AddressState.
        The router address state. This field is only valid if addressType is equal to IPV6_ADDR_TYPE_ROUTER.

        :return: The router_address_state of this IpV6AddressState.
        :rtype: str
        :required/optional: optional
        """
        return self._router_address_state

    @router_address_state.setter
    def router_address_state(self, router_address_state):
        """
        Sets the router_address_state of this IpV6AddressState.
        The router address state. This field is only valid if addressType is equal to IPV6_ADDR_TYPE_ROUTER.

        :param router_address_state: The router_address_state of this IpV6AddressState.
        :type: str
        """
        allowed_values = ["unknown", "configured", "advertised", "stale", "__UNDEFINED"]
        if router_address_state not in allowed_values:
            raise ValueError(
                "Invalid value for `router_address_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._router_address_state = router_address_state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        if self is None:
           return None
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if self is None or other is None:
            return None
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

